@@ -21,10 +21,12 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 # DEALINGS IN THE SOFTWARE.
 
-from hy._compat import PY3
-
 import traceback
 
+from clint.textui import colored
+
+from hy._compat import PY3
+
 
 class HyError(Exception):
     """
@@ -34,44 +36,6 @@ class HyError(Exception):
     pass
 
 
-try:
-    from clint.textui import colored
-except Exception:
-    class colored:
-
-        @staticmethod
-        def black(foo):
-            return foo
-
-        @staticmethod
-        def red(foo):
-            return foo
-
-        @staticmethod
-        def green(foo):
-            return foo
-
-        @staticmethod
-        def yellow(foo):
-            return foo
-
-        @staticmethod
-        def blue(foo):
-            return foo
-
-        @staticmethod
-        def magenta(foo):
-            return foo
-
-        @staticmethod
-        def cyan(foo):
-            return foo
-
-        @staticmethod
-        def white(foo):
-            return foo
-
-
 class HyCompileError(HyError):
     def __init__(self, exception, traceback=None):
         self.exception = exception
@@ -147,3 +111,11 @@ class HyTypeError(TypeError):
 
 class HyMacroExpansionError(HyTypeError):
     pass
+
+
+class HyIOError(HyError, IOError):
+    """
+    Trivial subclass of IOError and HyError, to distinguish between
+    IOErrors thrown by Hy itself as opposed to Hy programs.
+    """
+    pass
